@@ -1721,7 +1721,7 @@ class OMV(Provider):
     _view_name = Unicode("OMVView").tag(sync=True)
     _model_name = Unicode("OMVModel").tag(sync=True)
 
-    path = Unicode().tag(sync=True)
+    path = Unicode("/v2/vectortiles/core/mc").tag(sync=True)
     platform = Instance(Platform).tag(sync=True, **widget_serialization)
     style = Instance(Style).tag(sync=True, **widget_serialization)
 
@@ -1742,7 +1742,7 @@ class MarkerCluster(Provider):
         The minimum point weight sum to form a cluster.
     min_zoom: Int, default 0
         The minimum supported zoom level.
-    maz_zoom: Int, default 22
+    max_zoom: Int, default 22
         The maximum supported zoom level.
     """
 
@@ -1758,6 +1758,43 @@ class MarkerCluster(Provider):
     evt_type = Unicode("tap").tag(sync=True)
 
 
+class ImageTileProvider(Provider):
+    """ImageTileProvider class.
+    
+    Provider for loading data from XYZ tile setvers and WMTS sources.
+    
+    Attributes
+    ----------
+    url: string
+        A string representing provider's URL.
+    min_zoom: Int, default 0
+        The minimum supported zoom level.
+    max_zoom: Int, default 22
+        The maximum supported zoom level.
+    opacity: float default 1.0
+        The opacity to use for the rendering of the provided tiles in range [0..1] where 0.0 means full 
+        transparent and 1.0 means full opaque.
+    tile_size: Int, default 256
+        The size of a tile as edge length in pixels. 
+        It must be 2^n where n is in the range [0 ... 30].
+    headers: Dict
+        A dictionaary of headers to be sent with each request made by the provider.
+    attribution: string
+        Tiles service attribution.
+    """
+    
+    _view_name = Unicode("ImageTileProviderView").tag(sync=True)
+    _model_name = Unicode("ImageTileProviderModel").tag(sync=True)
+    
+    url = Unicode().tag(sync=True)
+    min_zoom = Int(default_value=0).tag(sync=True)
+    max_zoom = Int(default_value=22).tag(sync=True)
+    opacity = Float(default_value=1.0).tag(sync=True)
+    tile_size = Int(default_value=256).tag(sync=True)
+    headers = Dict(default_value={}).tag(sync=True)
+    attribution = Unicode().tag(sync=True)
+
+
 class Map(DOMWidget, InteractMixin):
     """Map class.
 
@@ -1836,11 +1873,13 @@ class Map(DOMWidget, InteractMixin):
         return proposal.value
 
     def add_layer(self, layer):
+        """Add layer from map."""
         if layer.model_id in self._layer_ids:
             raise Exception("layer already on map: %r" % layer)
         self.layers = tuple([l for l in self.layers] + [layer])
 
     def remove_layer(self, layer):
+        """Remove layer from map."""
         if layer.model_id not in self._layer_ids:
             raise Exception("layer not on map: %r" % layer)
         self.layers = tuple([l for l in self.layers if l.model_id != layer.model_id])
@@ -1860,11 +1899,13 @@ class Map(DOMWidget, InteractMixin):
         return proposal.value
 
     def add_object(self, object):
+        """Add object to map."""
         if object.model_id in self._object_ids:
             raise Exception("object already on map: %r" % object)
         self.objects = tuple([o for o in self.objects] + [object])
 
     def add_objects(self, objects: list):
+        """Add objects to map."""
         cur_objs = list(self.objects)
         for object in objects:
             if object.model_id in self._object_ids:
@@ -1873,6 +1914,7 @@ class Map(DOMWidget, InteractMixin):
         self.objects = tuple(cur_objs)
 
     def remove_object(self, object):
+        """Remove object from map."""
         if object.model_id not in self._object_ids:
             raise Exception("object not on map: %r" % object)
         self.objects = tuple([o for o in self.objects if o.model_id != object.model_id])
@@ -1892,11 +1934,13 @@ class Map(DOMWidget, InteractMixin):
         return proposal.value
 
     def add_control(self, control):
+        """Add control to map."""
         if control.model_id in self._control_ids:
             raise Exception("control already on map: %r" % control)
         self.controls = tuple([o for o in self.controls] + [control])
 
     def remove_control(self, control):
+        """Remove control from map."""
         if control.model_id not in self._control_ids:
             raise Exception("control not on map: %r" % control)
         self.controls = tuple([o for o in self.controls if o.model_id != control.model_id])
@@ -1930,3 +1974,36 @@ class Map(DOMWidget, InteractMixin):
         if bubble.model_id not in self._bubble_ids:
             raise Exception("control not on map: %r" % bubble)
         self.bubbles = tuple([b for b in self.bubbles if b.model_id != bubble.model_id])
+
+    def __iadd__(self, item):
+        if isinstance(item, Layer):
+            self.add_layer(item)
+        elif isinstance(item, Control):
+            self.add_control(item)
+        elif isinstance(item, Object):
+            self.add_object(item)
+        elif isinstance(item, InfoBubble):
+            self.add_bubble(item)
+        return self
+
+    def __isub__(self, item):
+        if isinstance(item, Layer):
+            self.remove_layer(item)
+        elif isinstance(item, Control):
+            self.remove_control(item)
+        elif isinstance(item, Object):
+            self.remove_object(item)
+        elif isinstance(item, InfoBubble):
+            self.remove_bubble(item)
+        return self
+
+    def __add__(self, item):
+        if isinstance(item, Layer):
+            self.add_layer(item)
+        elif isinstance(item, Control):
+            self.add_control(item)
+        elif isinstance(item, Object):
+            self.add_object(item)
+        elif isinstance(item, InfoBubble):
+            self.add_bubble(item)
+        return self
